@@ -24,7 +24,9 @@ package XML::Stream::XPath;
 
 use 5.006_001;
 use strict;
-use vars qw( %FUNCTIONS );
+use vars qw( $VERSION %FUNCTIONS );
+
+$VERSION = "1.20";
 
 use XML::Stream::XPath::Value;
 use XML::Stream::XPath::Op;
